function T=cheby(x,d)
% Cheby - Chebyshev-Vandermonde matrix
%
% Inputs:  x, mxk vector
%          d, scalar

% Output: t: mx(d+1) matrix
%
% x: nodes in [-1,+1]^k
% d: max. degree of the polynomials
%
% Author: Marco Maffezzoli, Ver. 3.0.1, 05/2009.
%

[m,k]=size(x);
n=d+1;
x=acos(x);
D=0:d;
D=D(ones(m,1),:);
if k==1
    T=Tn(x,D);
else
    C=zeros(m,n,k);
    for j=1:k
        C(:,:,j)=Tn(x(:,j),D);
    end
    T=kr(C);
end

end

function T=kr(C)

[~,n,k]=size(C);
T=C(:,:,k);
q=(1:n)';
for j=k-1:-1:1
    z=repmat(T,1,n);
    q1=q(:,ones(1,size(T,2)))';
    T=C(:,q1(:),j).*z;
end

end

function T=Tn(x,D)

n=size(D,2);
T=cos(D.*x(:,ones(1,n)));

end