function h=chebypol(x,c,a,b)
% ChebyPol - Polinomial in the Chebyshev polinomials
%
% Inputs:  x, mxk vector
%          c, nxz vector
%          a, 1xk vector (optional)
%          b, 1xk vector, b>a (optional)

% Output:  y, mx1 vector
%
% The function calcolates the weighted sum of n Chebishev polinomials of
% degree 0..n-1, evaluated at each point in x, using the coefficients in
% each column of c as weights.
% Note that x(:,j) takes values in [-1,+1] if a and b are not passed,
% otherwise it takes values in [a(j),b(j)].
%
% Author: Marco Maffezzoli. Ver. 1.0.2, 05/2009.
%

d=round(size(c,1)^(1/size(x,2))-1);
if nargin==4
    n=size(x,1);
    a=a(ones(n,1),:);
    b=b(ones(n,1),:);
    x=2*(x-a)./(b-a)-1;
end
T=cheby(x,d);
h=real(T*c);

end